#
# spec file for package solarus
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           solarus
Version:        1.6.0
Release:        1.15
Summary:        Zelda-like game engine
License:        GPL-3.0-or-later
Group:          Amusements/Games/RPG
Url:            http://www.solarus-engine.org/
Source:         http://www.solarus-games.org/downloads/solarus/%{name}-%{version}-src.tar.gz
# PATCH-FIX-UPSTREAM solarus-1.6.0-fix-desktop-exec.patch -- wrong Exec field in desktop file
Patch0:         solarus-1.6.0-fix-desktop-exec.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  physfs-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(luajit)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)

%description
Solarus is a Zelda-like game engine written in C++.

%package -n libsolarus1
Summary:        Zelda-like game engine
Group:          System/Libraries

%description -n libsolarus1
Solarus is a Zelda-like game engine written in C++.

%package devel
Summary:        Development files for solarus
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
Development files for solarus, including header-files.

%prep
%setup -q
%patch0 -p1

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install

%if 0%{?suse_version} < 1330
%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%endif

%post   -n libsolarus1 -p /sbin/ldconfig
%postun -n libsolarus1 -p /sbin/ldconfig

%files
%doc changelog.txt readme.md
%license license.txt
%{_bindir}/solarus-launcher
%{_bindir}/solarus-run
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_libdir}/libsolarus-gui.so
%{_mandir}/man6/solarus*

%files -n libsolarus1
%{_libdir}/libsolarus.so.*

%files devel
%{_includedir}/solarus
%{_libdir}/libsolarus.so

%changelog
* Sat Dec 22 2018 antoine.belvire@opensuse.org
- Update to 1.6.0:
  * Engine changes:
    + Solarus 1.5 quests are still supported by Solarus 1.6.
    + Add support of OpenGL shaders.
    + Replaced SDL renderer by a custom GL backend.
    + Improve the performance of loading images.
    + Maps can now use multiple tilesets.
    + Animated tile patterns can now have any frame number and
    delay.
    + Treasure dialogs are now optional.
    + Allow entities to have a non-multiple of 8 size.
    + Don't center the hero on non-blocking streams.
    + Allow pickables to follow streams.
    + Blocks can now be moved multiple times.
    + Add support of .otf fonts.
    + Improve Lua error messages.
    + CLI can accept an archive's path as argument.
    + Bug fixes.
  * Solarus launcher GUI changes:
    + Show the path and the compatibility format of each quest.
    + Lua console: provide variables game, map, entities and tp
    function.
    + Clear the console when a quest is started.
    + FileDialog now expects a file, either quest.dat or an
    archive (.solarus, .zip).
  * Lua API changes:
    + This release adds new features and deprecates a few ones but
    does not introduce any incompatibility.
    + See installed changelog.txt for full changelog.
- Update build dependencies:
  * Add pkgconfig(gl): Was already pulled by other dependencies
    but now it's actually used.
- Update patches:
  * Drop appdata.patch: Fixed upstream.
  * Add solarus-1.6.0-fix-desktop-exec.patch: Fix executable name
    in desktop file.
* Mon Aug 14 2017 aloisio@gmx.com
- Update to 1.5.3
  * Speed up loading maps by keeping tilesets in a cache (#1019).
  * Fix text_surface:set_horizontal/vertical_alignment() not
    working.
  * Fix parallax dynamic tiles still displayed when disabled or
    invisible.
  * Improve error message of non-square tile patterns with diagonal
    obstacles.
- Dropped luajit-5_1-2.1.patch and icons-desktop-man.patch
  (merged upstream)
* Sat Feb 18 2017 mailaender@opensuse.org
- Add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
* Wed Jan 25 2017 jengelh@inai.de
- Implement shared library packaging guideline.
  Trim filler words from description.
* Tue Jan 24 2017 mailaender@opensuse.org
- New upstream version 1.5.1
- build the Qt5 quest launcher GUI
- remove fix-libsuffix.patch (included upstream)
- remove fix-luajit-cmake.patch (included upstream)
- add luajit-5_1-2.1.patch to fix the build with LuaJIT 2.1
- add icons-desktop-man.patch to complete the cmake installation
* Mon Jan 25 2016 rpm@fthiessen.de
- New upstream version 1.4.5:
  * Fix file name not shown when there is an error in dialogs file.
  * Fix saving special characters in data files.
  * Fix sol.main.load_file() returning a string instead of
    nil on error.
  * Fix performance issue when sprites have huge frame delays.
  * Fix collisions triggered for removed entities.
  * Fix hero disappearing if lifting animation has less
    than 5 frames.
  * Fix collisions with diagonal dynamic tiles larger than 8x8.
  * Fix path finding movement not working with NPCs.
  * Fix stuck on non-traversable dynamic tiles covered
    by traversables.
  * Fix collision detection of custom entities that do not move.
  * Fix pickables with special movement falling in holes too early.
  * Fix blocking streams not working when the hero's
    speed is greater.
* Sat Nov 21 2015 rpm@fthiessen.de
- Updated to 1.4.4:
  * spec file clean up
  * Added fix-libsuffix.patch to install library into /usr/lib64
    on e.g. x86_64 instead /usr/lib
  * Added fix-luajit-cmake.patch to detect luajit headers in
    include path with lua_suffix.
* Wed Jul  2 2014 mailaender@opensuse.org
- Adapted for SUSE
- Update to 1.2.0
* Fri Jan  3 2014 huaren.zhong@gmail.com
- Rebuild for Fedora
* Wed Dec 28 2011 giacomosrv@gmail.com
- packaged solarus version 0.9.0
